Learn R Programming

intRinsic (version 1.1.2)

Swissroll: Generates a noise-free Swiss roll dataset

Description

The function creates a three-dimensional dataset with coordinates following the Swiss roll mapping, transforming random uniform data points sampled on the interval (0,10).

Usage

Swissroll(n)

Value

a three-dimensional data.frame containing the coordinates of the points generated via the Swiss roll mapping.

Arguments

n

number of observations contained in the output dataset.

Examples

Run this code
Data <- Swissroll(1000)

Run the code above in your browser using DataLab