GrideUse this method without the .gride_bayes suffix.
It displays the traceplot of the chain generated
with Metropolis-Hasting updates to visually assess mixing and convergence.
Alternatively, it is possible to plot the posterior density.
# S3 method for gride_bayes
autoplot(
object,
traceplot = FALSE,
title = "Bayesian Gride - Posterior distribution",
...
)object of class ggplot.
It could represent the traceplot of the posterior simulations for the
Bayesian Gride model (traceplot = TRUE) or a density plot
of the simulated posterior distribution (traceplot = FALSE).
object of class gride_bayes.
It is obtained using the output of the gride function when
method = "bayes".
logical. If FALSE, the function returns a plot of the
posterior density. If TRUE, the function returns the traceplots of the
MCMC used to simulate from the posterior distribution.
optional string to display as title.
other arguments passed to specific methods.
gride
Other autoplot methods:
autoplot.Hidalgo(),
autoplot.twonn_bayes(),
autoplot.twonn_linfit(),
autoplot.twonn_mle()