Learn R Programming

intRinsic (version 1.1.2)

autoplot.gride_mle: Plot the simulated bootstrap sample for the MLE Gride

Description

Use this method without the .gride_mle suffix. It displays the density plot of sample obtained via parametric bootstrap for the Gride model.

Usage

# S3 method for gride_mle
autoplot(object, title = "MLE Gride - Bootstrap sample", ...)

Value

object of class ggplot. It displays the density plot of the sample generated via parametric bootstrap to help the visual assessment of the uncertainty of the id estimates.

Arguments

object

object of class gride_mle. It is obtained using the output of the gride function when method = "mle".

title

title for the plot.

...

other arguments passed to specific methods.

See Also

gride