TWO-NN model estimated via the Bayesian
approachUse this method without the .twonn_bayes suffix.
The function returns the density plot of the
posterior distribution computed with the bayes method.
# S3 method for twonn_bayes
autoplot(
object,
plot_low = 0,
plot_upp = NULL,
by = 0.05,
title = "Bayesian TWO-NN",
...
)ggplot2 object displaying the posterior
distribution of the intrinsic dimension parameter.
object of class twonn_bayes, the output of the
twonn function when method = "bayes".
lower bound of the interval on which the posterior density is plotted.
upper bound of the interval on which the posterior density is plotted.
step-size at which the sequence spanning the interval is incremented.
character string used as title of the plot.
other arguments passed to specific methods.
twonn
Other autoplot methods:
autoplot.Hidalgo(),
autoplot.gride_bayes(),
autoplot.twonn_linfit(),
autoplot.twonn_mle()