Learn R Programming

intRinsic (version 1.1.2)

autoplot.twonn_linfit: Plot the output of the TWO-NN model estimated via least squares

Description

Use this method without the .twonn_linfit suffix. The function returns the representation of the linear regression that is fitted with the linfit method.

Usage

# S3 method for twonn_linfit
autoplot(object, title = "TWO-NN Linear Fit", ...)

Value

a ggplot2 object displaying the goodness of the linear fit of the TWO-NN model.

Arguments

object

object of class twonn_linfit, the output of the twonn function when method = "linfit".

title

string used as title of the plot.

...

other arguments passed to specific methods.

See Also

twonn

Other autoplot methods: autoplot.Hidalgo(), autoplot.gride_bayes(), autoplot.twonn_bayes(), autoplot.twonn_mle()