Learn R Programming

intRinsic (version 1.1.2)

intRinsic-package: intRinsic: Likelihood-Based Intrinsic Dimension Estimators

Description

logo

Provides functions to estimate the intrinsic dimension of a dataset via likelihood-based approaches. Specifically, the package implements the 'TWO-NN' and 'Gride' estimators and the 'Hidalgo' Bayesian mixture model. In addition, the first reference contains an extended vignette on the usage of the 'TWO-NN' and 'Hidalgo' models. References: Denti (2023, tools:::Rd_expr_doi("10.18637/jss.v106.i09")); Allegra et al. (2020, tools:::Rd_expr_doi("10.1038/s41598-020-72222-0")); Denti et al. (2022, tools:::Rd_expr_doi("10.1038/s41598-022-20991-1")); Facco et al. (2017, tools:::Rd_expr_doi("10.1038/s41598-017-11873-y")); Santos-Fernandez et al. (2021, tools:::Rd_expr_doi("10.1038/s41598-022-20991-1")).

Arguments

Author

Maintainer: Francesco Denti francescodenti.personal@gmail.com (ORCID) [copyright holder]

Authors:

See Also