GrideUse this method without the .gride_mle suffix.
It displays the density plot of sample obtained via
parametric bootstrap for the Gride model.
# S3 method for gride_mle
autoplot(object, title = "MLE Gride - Bootstrap sample", ...)object of class ggplot. It displays the
density plot of the sample generated via parametric bootstrap to help the
visual assessment of the uncertainty of the id estimates.
object of class gride_mle.
It is obtained using the output of the gride function when
method = "mle".
title for the plot.
other arguments passed to specific methods.
gride