TWO-NN model estimated via the Maximum
Likelihood approachUse this method without the .twonn_mle suffix.
The function returns the point estimate along with the confidence bands
computed via the mle method.
# S3 method for twonn_mle
autoplot(object, title = "MLE TWO-NN", ...)ggplot2 object displaying the point estimate
and confidence interval obtained via the maximum likelihood approach of the
id parameter.
object of class twonn_mle, the output of the
twonn function when method = "mle".
character string used as title of the plot.
other arguments passed to specific methods.
twonn
Other autoplot methods:
autoplot.Hidalgo(),
autoplot.gride_bayes(),
autoplot.twonn_bayes(),
autoplot.twonn_linfit()