id_by_class: Stratification of the id by an external categorical variable
Description
The function computes summary statistics (mean, median, and standard
deviation) of the post-processed chains of the intrinsic dimension stratified
by an external categorical variable.
Usage
id_by_class(object, class)
# S3 method for hidalgo_class
print(x, ...)
Value
a data.frame containing the posterior id means,
medians, and standard deviations stratified by the levels of the variable
class.
Arguments
object
object of class Hidalgo, the output of the
Hidalgo() function.
class
factor according to the observations should be stratified by.
x
object of class hidalgo_class, the output of the id_by_class() function.